@@ -9,13 +9,12 @@ display_size = [0,0]
 eventsl = None
 system("clear")
 print("Pygame Extra 1.6.X is installed correctly!")
-scriptpath = str(__file__).replace("__init__.py",'')
+scriptpath = str(__file__).replace("pygame-extra/__init__.py",'')
+print('at: ' + scriptpath)
 #RESOURCE LOADING# \/
 slider_image = None
 #RESOURCE LOADING# /\
 #Emergency call functions# \/
-def PE___entry___PE():
-    print('test')
 def error(textS):
   pygame.quit()
   print(textS)
